summaryrefslogtreecommitdiff
path: root/riscos/url_complete.h
diff options
context:
space:
mode:
Diffstat (limited to 'riscos/url_complete.h')
-rw-r--r--riscos/url_complete.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/riscos/url_complete.h b/riscos/url_complete.h
index 12f640086..6a4660e4a 100644
--- a/riscos/url_complete.h
+++ b/riscos/url_complete.h
@@ -79,12 +79,12 @@ void ro_gui_url_complete_redraw(wimp_draw *redraw);
/**
* Handle mouse movement over the URL completion window.
*
- * \param pointer the pointer state
- */
+ * \param *entering The pointer entering data block.
+ */
-void ro_gui_url_complete_mouse_at(wimp_pointer *pointer);
+void ro_gui_url_complete_entering(wimp_entering *entering);
/**
@@ -79,12 +79,12 @@ void ro_gui_url_complete_redraw(wimp_draw *redraw);
/**
- * Handle mouse movement over the URL completion window.
+ * Handle the pointer entering the URL completion window.
*